@@ -66,6 +66,56 @@ class WebClient(BaseClient):
         removed at anytime.
     """
 
+    def admin_apps_approve(
+        self, *, app_id: str = None, request_id: str = None, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Approve an app for installation on a workspace.
+
+        Either app_id or request_id is required.
+        These IDs can be obtained either directly via the app_requested event,
+        or by the admin.apps.requests.list method.
+
+        Args:
+            app_id (str): The id of the app to approve. e.g. 'A12345'
+            request_id (str): The id of the request to approve. e.g. 'Ar12345'
+        Raises:
+            SlackRequestError: If niether or both the `app_id` and `request_id` args are specified.
+        """
+        self._validate_xoxp_token()
+
+        if app_id:
+            kwargs.update({"app_id": app_id})
+        elif request_id:
+            kwargs.update({"request_id": request_id})
+        else:
+            raise e.SlackRequestError(
+                "The app_id or request_id argument must be specified."
+            )
+
+        return self.api_call("admin.apps.approve", json=kwargs)
+
+    def admin_apps_requests_list(self, **kwargs) -> Union[Future, SlackResponse]:
+        """List app requests for a team/workspace."""
+        self._validate_xoxp_token()
+        return self.api_call("admin.apps.requests.list", http_verb="GET", params=kwargs)
+
+    def admin_apps_restrict(self, **kwargs) -> Union[Future, SlackResponse]:
+        """Restrict an app for installation on a workspace."""
+        self._validate_xoxp_token()
+        return self.api_call("admin.apps.restrict", json=kwargs)
+
+    def admin_users_session_reset(
+        self, *, user_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Wipes all valid sessions on all devices for a given user.
+
+        Args:
+            user_id (str): The ID of the user to wipe sessions for. e.g. 'W12345678'
+        """
+        self._validate_xoxp_token()
+        kwargs.update({"user_id": user_id})
+        return self.api_call("admin.users.session.reset", json=kwargs)
+
     def api_test(self, **kwargs) -> Union[Future, SlackResponse]:
         """Checks API calling code."""
         return self.api_call("api.test", json=kwargs)
@@ -667,6 +717,49 @@ class WebClient(BaseClient):
         self._validate_xoxp_token()
         return self.api_call("files.list", http_verb="GET", params=kwargs)
 
+    def files_remote_info(self, **kwargs) -> Union[Future, SlackResponse]:
+        """Retrieve information about a remote file added to Slack."""
+        return self.api_call("files.remote.info", http_verb="GET", params=kwargs)
+
+    def files_remote_list(self, **kwargs) -> Union[Future, SlackResponse]:
+        """Retrieve information about a remote file added to Slack."""
+        return self.api_call("files.remote.list", http_verb="GET", params=kwargs)
+
+    def files_remote_add(
+        self, *, external_id: str, external_url: str, title: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Adds a file from a remote service.
+
+        Args:
+            external_id (str): Creator defined GUID for the file. e.g. '123456'
+            external_url (str): URL of the remote file. e.g. 'http://example.com/my_cloud_service_file/abc123'
+            title (str): Title of the file being shared. e.g. 'Danger, High Voltage!'
+        """
+        kwargs.update(
+            {"external_id": external_id, "external_url": external_url, "title": title}
+        )
+        return self.api_call("files.remote.add", http_verb="GET", params=kwargs)
+
+    def files_remote_update(self, **kwargs) -> Union[Future, SlackResponse]:
+        """Updates an existing remote file."""
+        return self.api_call("files.remote.update", http_verb="GET", params=kwargs)
+
+    def files_remote_remove(self, **kwargs) -> Union[Future, SlackResponse]:
+        """Remove a remote file."""
+        return self.api_call("files.remote.remove", http_verb="GET", params=kwargs)
+
+    def files_remote_share(
+        self, *, channels: Union[str, List[str]], **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Share a remote file into a channel.
+
+        Args:
+            channels (list): Comma-separated list of channel IDs where the file will be shared.
+                e.g. ['C1234567890', 'C2345678901']
+        """
+        kwargs.update({"channels": channels})
+        return self.api_call("files.remote.share", http_verb="GET", params=kwargs)
+
     def files_revokePublicURL(
         self, *, file: str, **kwargs
     ) -> Union[Future, SlackResponse]:
@@ -1031,10 +1124,8 @@ class WebClient(BaseClient):
             client_secret (str): Issued when you created your application. e.g. '33fea0113f5b1'
             code (str): The code param returned via the OAuth callback. e.g. 'ccdaa72ad'
         """
-        kwargs.update(
-            {"client_id": client_id, "client_secret": client_secret, "code": code}
-        )
-        return self.api_call("oauth.access", data=kwargs)
+        headers = {"client_id": client_id, "client_secret": client_secret, "code": code}
+        return self.api_call("oauth.access", data=kwargs, headers=headers)
 
     def pins_add(self, *, channel: str, **kwargs) -> Union[Future, SlackResponse]:
         """Pins an item to a channel.
@@ -1415,3 +1506,70 @@ class WebClient(BaseClient):
         """Set the profile information for a user."""
         self._validate_xoxp_token()
         return self.api_call("users.profile.set", json=kwargs)
+
+    def views_open(
+        self, *, trigger_id: str, view: dict, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Open a view for a user.​
+
+        Open a modal with a user by exchanging a trigger_id received
+        from another interaction.
+​
+        See the modals (https://api.slack.com/block-kit/surfaces/modals)
+        documentation to learn how to obtain triggers from interactive components.
+
+        Args:
+            trigger_id (str): Exchange a trigger to post to the user.
+                e.g. '12345.98765.abcd2358fdea'
+            view (dict): The view payload.
+        """
+        kwargs.update({"trigger_id": trigger_id, "view": view})
+        return self.api_call("views.open", json=kwargs)
+
+    def views_push(
+        self, *, trigger_id: str, view: dict, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Push a view onto the stack of a root view.
+
+        Push a new view onto the existing view stack by passing a view
+        payload and a valid trigger_id generated from an interaction
+        within the existing modal.
+
+        Read the modals documentation (https://api.slack.com/block-kit/surfaces/modals)
+        to learn more about the lifecycle and intricacies of views.
+
+        Args:
+            trigger_id (str): Exchange a trigger to post to the user.
+                e.g. '12345.98765.abcd2358fdea'
+            view (dict): The view payload.
+        """
+        kwargs.update({"trigger_id": trigger_id, "view": view})
+        return self.api_call("views.push", json=kwargs)
+
+    def views_update(
+        self, *, external_id: str = None, view_id: str = None, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Update an existing view.
+
+        Update a view by passing a new view definition along with the
+        view_id returned in views.open or the external_id.
+
+        See the modals documentation (https://api.slack.com/block-kit/surfaces/modals#updating_views)
+        to learn more about updating views and avoiding race conditions with the hash argument.
+
+        Args:
+            external_id (str): A unique identifier of the view set by the developer.
+                e.g. 'bmarley_view2'
+            view_id (str): A unique identifier of the view to be updated.
+                e.g. 'VMM512F2U'
+        Raises:
+            SlackRequestError: Either view_id or external_id is required.
+        """
+        if external_id:
+            kwargs.update({"external_id": external_id})
+        elif view_id:
+            kwargs.update({"view_id": view_id})
+        else:
+            raise e.SlackRequestError("Either view_id or external_id is required.")
+
+        return self.api_call("views.update", json=kwargs)
